@@ -35,7 +35,7 @@ class FindIncompatibleKioTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
 
     void initTestCase();
 
